@@ -958,7 +958,7 @@ Tripletail::Session オブジェクトを取得。
 
 ユニークなセッションキーを取得する。
 
-セッションキーは64bit符号無し整数値となる。
+セッションキーは64bit整数値の負の数を除いた範囲となる。
 
 Perlでは通常32bit整数値までしか扱えないため、セッションキーを数値として扱ってはならない。
 
@@ -995,7 +995,7 @@ Perlでは通常32bit整数値までしか扱えないため、セッション
 
 セッションに値を設定する。
 
-設定できる値は '64bit符号無し整数' のみ。
+設定できる値は '64bit符号無し整数' のみ（※PostgreSQL利用時は64bit整数値のみ）。
 その他のデータを管理したい場合は、セッションキーを用いて別途実装する必要がある。
 
 doubleモードの場合は、SSL起動時の場合に限り、両方のセッションに書き込まれる。
